pub struct EndOfLogMarker {
pub temporary: bool,
}Expand description
Payload stored in the end-of-log section to signal whether the log was cleanly closed.
Fields
temporary: boolTrait Implementations
Sourceimpl<'__de, __Context> BorrowDecode<'__de, __Context> for EndOfLogMarker
impl<'__de, __Context> BorrowDecode<'__de, __Context> for EndOfLogMarker
Sourcefn borrow_decode<__D: BorrowDecoder<'__de, Context = __Context>>(
decoder: &mut __D,
) -> Result<Self, DecodeError>
fn borrow_decode<__D: BorrowDecoder<'__de, Context = __Context>>( decoder: &mut __D, ) -> Result<Self, DecodeError>
Attempt to decode this type with the given BorrowDecode.
Sourceimpl Clone for EndOfLogMarker
impl Clone for EndOfLogMarker
Sourcefn clone(&self) -> EndOfLogMarker
fn clone(&self) -> EndOfLogMarker
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EndOfLogMarker
impl Debug for EndOfLogMarker
Sourceimpl<__Context> Decode<__Context> for EndOfLogMarker
impl<__Context> Decode<__Context> for EndOfLogMarker