SectionHeader

Struct SectionHeader 

pub struct SectionHeader {
    pub magic: [u8; 2],
    pub block_size: u16,
    pub entry_type: UnifiedLogType,
    pub offset_to_next_section: u32,
    pub used: u32,
    pub is_open: bool,
}
Each concurrent sublogger is tracked through a section header. They form a linked list of sections. The entry type is used to identify the type of data in the section.

Fields

magic: [u8; 2]block_size: u16entry_type: UnifiedLogTypeoffset_to_next_section: u32used: u32is_open: bool