pub struct SectionHeader {
pub magic: [u8; 2],
pub block_size: u16,
pub entry_type: UnifiedLogType,
pub offset_to_next_section: u32,
pub used: u32,
pub is_open: bool,
}Expand description
Each concurrent sublogger is tracked through a section header. They form a linked list of sections. The entry type is used to identify the type of data in the section.
Fields
magic: [u8; 2]block_size: u16entry_type: UnifiedLogTypeoffset_to_next_section: u32used: u32is_open: boolTrait Implementations
Sourceimpl<'__de, __Context> BorrowDecode<'__de, __Context> for SectionHeader
impl<'__de, __Context> BorrowDecode<'__de, __Context> for SectionHeader
Sourcefn borrow_decode<__D: BorrowDecoder<'__de, Context = __Context>>(
decoder: &mut __D,
) -> Result<Self, DecodeError>
fn borrow_decode<__D: BorrowDecoder<'__de, Context = __Context>>( decoder: &mut __D, ) -> Result<Self, DecodeError>
Attempt to decode this type with the given BorrowDecode.
Sourceimpl Debug for SectionHeader
impl Debug for SectionHeader
Sourceimpl<__Context> Decode<__Context> for SectionHeader
impl<__Context> Decode<__Context> for SectionHeader
Sourceimpl Default for SectionHeader
impl Default for SectionHeader
Sourceimpl Display for SectionHeader
impl Display for SectionHeader